-----------------------------------------------------------------------------------------------
-- Client Lua Script for GuildRosterFixed
-- Copyright (c) NCsoft. All rights reserved

-- Credits: Quickgric used his code to assist in using Gemini hooks
-----------------------------------------------------------------------------------------------
 
require "Window"
require "GuildLib"
 
-----------------------------------------------------------------------------------------------
-- GuildRosterFixed Module Definition
-----------------------------------------------------------------------------------------------
local GuildRosterFixed = Apollo.GetPackage("Gemini:Addon-1.1").tPackage:NewAddon("GuildRosterFixed", false, {"GuildContentRoster", "Circles", "Gemini:Hook-1.0"}, "Gemini:Hook-1.0") 
local logger = nil

local wndMain = nil
local vScrollPos = nil
local currentWindow = nil
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------

function GuildRosterFixed:OnInitialize()
	-- Debugging
	--local GeminiLogging = Apollo.GetPackage("Gemini:Logging-1.2").tPackage
	--logger = GeminiLogging:GetLogger()
	
	self.GuildRoster = Apollo.GetAddon("GuildContentRoster")
	self.CircleRoster = Apollo.GetAddon("Circles")
	
	-- Hooks
	self:RawHook(self.GuildRoster, "BuildRosterList")
	self:RawHook(self.GuildRoster, "OnToggleRoster")
	self:RawHook(self.GuildRoster, "OnGuildMemberChange")
	self:RawHook(self.GuildRoster, "OnClose")
	
	self:RawHook(self.CircleRoster, "OnGuildMemberChange", "OnCircleMemberChange")
	self:RawHook(self.CircleRoster, "OnOfflineTimeUpdate")
	self:RawHook(self.CircleRoster, "OnGuildRankChange")
	self:RawHook(self.CircleRoster, "OnGuildRoster")
	
	
	self.xml = XmlDoc.CreateFromFile("GuildRosterFixed.xml")
end

--
--		HOOK FUNCTIONS
--
function GuildRosterFixed:BuildRosterList(luaCaller, guildCurr, tRoster)
	for key, tCurr in pairs(tRoster) do
		if string.find(tCurr.strNote, "<") then
			tCurr.strNote = string.gsub(tCurr.strNote, "<", "")
		end
		if string.find(tCurr.strNote, ">") then
			tCurr.strNote = string.gsub(tCurr.strNote, ">", "")
		end
	end
	self.hooks[self.GuildRoster].BuildRosterList(luaCaller, guildCurr, tRoster)
end

function GuildRosterFixed:OnClose(luaCaller)
--	logger:info("OnClose")
	self.hooks[self.GuildRoster].OnClose(luaCaller)
end

function GuildRosterFixed:OnToggleRoster(luaCaller, wndParent)
--	logger:info("OnToggleRoster")
	wndMain = wndParent
	Apollo.StopTimer("OfflineTimeUpdate")
	self.hooks[self.GuildRoster].OnToggleRoster(luaCaller, wndParent)
end

function GuildRosterFixed:OnGuildMemberChange(luaCaller, guildCurr)
--	logger:info("GuildMemberChange")
--	logger:info(guildCurr:GetName())
	if wndMain ~= nil then
		vScrollPos = wndMain:FindChild("RosterGrid"):GetVScrollPos()
		self.hooks[self.GuildRoster].OnGuildMemberChange(luaCaller, guildCurr)
		wndMain:FindChild("RosterGrid"):SetVScrollPos(vScrollPos)
	else
		self.hooks[self.GuildRoster].OnGuildMemberChange(luaCaller, guildCurr)
	end
end

function GuildRosterFixed:OnCircleMemberChange(luaCaller, guildCurr)
--	logger:info("CircleMemberChange")
--	logger:info(guildCurr:GetName())
	if guildCurr and guildCurr:GetType() == GuildLib.GuildType_Guild then
--		logger:info("In guild window")
		return
	end
	self.hooks[self.CircleRoster].OnGuildMemberChange(luaCaller, guildCurr)
end

function GuildRosterFixed:OnOfflineTimeUpdate(luaCaller)
--	logger:info("Offline time update")

	self.hooks[self.CircleRoster].OnOfflineTimeUpdate(luaCaller)
end

function GuildRosterFixed:OnGuildRankChange(luaCaller, guildCurr)
--	logger:info("OnCircleRankChange")

	self.hooks[self.CircleRoster].OnGuildRankChange(luaCaller, guildCurr)
end

-- Circle
function GuildRosterFixed:OnGuildRoster(luaCaller, guildCurr, tRoster)
	--logger:info("OnCircleRoster")
	--logger:info(guildCurr:GetName())
	if guildCurr and guildCurr:GetType() == GuildLib.GuildType_Guild then
		--logger:info("In guild window")
		return
	end
	--logger:info("Not in guild window")
	self.hooks[self.CircleRoster].OnGuildRoster(luaCaller, guildCurr, tRoster)
end

--
-- 		OTHER FUNCTIONS
--
